@@ -7,60 +7,13 @@ Tests for L{incremental}.
 
 from __future__ import division, absolute_import
 
-import sys
 import operator
 
-from tempfile import mkdtemp
-
-from io import BytesIO
-
 from incremental import getVersionString, IncomparableVersions
 from incremental import Version, _inf
 
-from twisted.python.filepath import FilePath
 from twisted.trial.unittest import TestCase
 
-VERSION_4_ENTRIES = b"""\
-<?xml version="1.0" encoding="utf-8"?>
-<wc-entries
-   xmlns="svn:">
-<entry
-   committed-rev="18210"
-   name=""
-   committed-date="2006-09-21T04:43:09.542953Z"
-   url="svn+ssh://svn.twistedmatrix.com/svn/Twisted/trunk/twisted"
-   last-author="exarkun"
-   kind="dir"
-   uuid="bbbe8e31-12d6-0310-92fd-ac37d47ddeeb"
-   repos="svn+ssh://svn.twistedmatrix.com/svn/Twisted"
-   revision="18211"/>
-</wc-entries>
-"""
-
-VERSION_8_ENTRIES = b"""\
-8
-
-dir
-22715
-svn+ssh://svn.twistedmatrix.com/svn/Twisted/trunk
-"""
-
-VERSION_9_ENTRIES = b"""\
-9
-
-dir
-22715
-svn+ssh://svn.twistedmatrix.com/svn/Twisted/trunk
-"""
-
-VERSION_10_ENTRIES = b"""\
-10
-
-dir
-22715
-svn+ssh://svn.twistedmatrix.com/svn/Twisted/trunk
-"""
-
 
 class VersionsTests(TestCase):
 
@@ -374,39 +327,6 @@ class VersionsTests(TestCase):
     def testShort(self):
         self.assertEqual(Version('dummy', 1, 2, 3).short(), '1.2.3')
 
-    def test_goodSVNEntries_4(self):
-        """
-        Version should be able to parse an SVN format 4 entries file.
-        """
-        version = Version("dummy", 1, 0, 0)
-        self.assertEqual(
-            version._parseSVNEntries_4(BytesIO(VERSION_4_ENTRIES)), b'18211')
-
-    def test_goodSVNEntries_8(self):
-        """
-        Version should be able to parse an SVN format 8 entries file.
-        """
-        version = Version("dummy", 1, 0, 0)
-        self.assertEqual(
-            version._parseSVNEntries_8(BytesIO(VERSION_8_ENTRIES)), b'22715')
-
-    def test_goodSVNEntries_9(self):
-        """
-        Version should be able to parse an SVN format 9 entries file.
-        """
-        version = Version("dummy", 1, 0, 0)
-        self.assertEqual(
-            version._parseSVNEntries_9(BytesIO(VERSION_9_ENTRIES)), b'22715')
-
-    def test_goodSVNEntriesTenPlus(self):
-        """
-        Version should be able to parse an SVN format 10 entries file.
-        """
-        version = Version("dummy", 1, 0, 0)
-        self.assertEqual(
-            version._parseSVNEntriesTenPlus(BytesIO(VERSION_10_ENTRIES)),
-            b'22715')
-
     def test_getVersionString(self):
         """
         L{getVersionString} returns a string with the package name and the
@@ -493,123 +413,3 @@ class VersionsTests(TestCase):
         self.assertEqual(Version("foo", 1, 0, 0,
                                  release_candidate=2, dev=8).base(),
                          "1.0.0rc2dev8")
-
-    def test_git(self):
-
-        gitDir = FilePath(self.mktemp())
-        gitDir.makedirs()
-        gitDir.child("HEAD").setContent(b"ref: refs/heads/master\n")
-
-        heads = gitDir.child("refs").child("heads")
-        heads.makedirs()
-        heads.child("master").setContent(
-            b"a96d61d94949c0dc097d6e1c3515792e99a724d5\n")
-
-        version = Version("foo", 1, 0, 0)
-        self.assertEqual(version._parseGitDir(gitDir.path),
-                         "a96d61d94949c0dc097d6e1c3515792e99a724d5")
-
-
-class FormatDiscoveryTests(TestCase):
-    """
-    Tests which discover the parsing method based on the imported module name.
-    """
-    def setUp(self):
-        """
-        Create a temporary directory with a package structure in it.
-        """
-        self.entry = FilePath(mkdtemp())
-        self.addCleanup(self.entry.remove)
-
-        self.preTestModules = sys.modules.copy()
-        sys.path.append(self.entry.path)
-        pkg = self.entry.child("incremental_test_package")
-        pkg.makedirs()
-        pkg.child("__init__.py").setContent(
-            b"from incremental import Version\n"
-            b"version = Version('incremental_test_package', 1, 0, 0)\n")
-        self.svnEntries = pkg.child(".svn")
-        self.svnEntries.makedirs()
-
-    def tearDown(self):
-        """
-        Remove the imported modules and sys.path modifications.
-        """
-        sys.modules.clear()
-        sys.modules.update(self.preTestModules)
-        sys.path.remove(self.entry.path)
-
-    def checkSVNFormat(self, formatVersion, entriesText, expectedRevision):
-        """
-        Check for the given revision being detected after setting the SVN
-        entries text and format version of the test directory structure.
-        """
-        self.svnEntries.child("format").setContent(formatVersion + b"\n")
-        self.svnEntries.child("entries").setContent(entriesText)
-        self.assertEqual(self.getVersion()._getSVNVersion(), expectedRevision)
-
-    def getVersion(self):
-        """
-        Import and retrieve the Version object from our dynamically created
-        package.
-        """
-        import incremental_test_package
-        return incremental_test_package.version
-
-    def test_detectVersion4(self):
-        """
-        Verify that version 4 format file will be properly detected and parsed.
-        """
-        self.checkSVNFormat(b"4", VERSION_4_ENTRIES, b'18211')
-
-    def test_detectVersion8(self):
-        """
-        Verify that version 8 format files will be properly detected and
-        parsed.
-        """
-        self.checkSVNFormat(b"8", VERSION_8_ENTRIES, b'22715')
-
-    def test_detectVersion9(self):
-        """
-        Verify that version 9 format files will be properly detected and
-        parsed.
-        """
-        self.checkSVNFormat(b"9", VERSION_9_ENTRIES, b'22715')
-
-    def test_unparseableEntries(self):
-        """
-        Verify that the result is C{b"Unknown"} for an apparently supported
-        version for which parsing of the entries file fails.
-        """
-        self.checkSVNFormat(b"4", b"some unsupported stuff", b"Unknown")
-
-    def test_detectVersion10(self):
-        """
-        Verify that version 10 format files will be properly detected and
-        parsed.
-
-        Differing from previous formats, the version 10 format lacks a
-        I{format} file and B{only} has the version information on the first
-        line of the I{entries} file.
-        """
-        self.svnEntries.child("entries").setContent(VERSION_10_ENTRIES)
-        self.assertEqual(self.getVersion()._getSVNVersion(), b'22715')
-
-    def test_detectUnknownVersion(self):
-        """
-        Verify that a new version of SVN will result in the revision 'Unknown'.
-        """
-        self.checkSVNFormat(b"some-random-new-version", b"ooga booga!",
-                            b'Unknown')
-
-    def test_getVersionStringWithRevision(self):
-        """
-        L{getVersionString} includes the discovered revision number.
-        """
-        self.svnEntries.child("format").setContent(b"9\n")
-        self.svnEntries.child("entries").setContent(VERSION_10_ENTRIES)
-        version = getVersionString(self.getVersion())
-        self.assertEqual(
-            "incremental_test_package 1.0.0+r22715",
-            version)
-        self.assertTrue(isinstance(version, type("")))
